pyCarla
==========

A python module based on Linux commands for synthesizing MIDI events and files
from python code with ultra time precision using any kind of audio plugin!

See `docs <https://pycarla.readthedocs.org>`_ for more installation and more info.

Credits
=======

#. `Federico Simonetta <https://federicosimonetta.eu.org>`_
    ``federico.simonetta`` ``at`` ``unimi.it``
